@@ -7,7 +7,7 @@
 #-------------------------------------------------------------------------
 pa.scABE   <- function(CV, theta0=0.9, targetpower=0.8, minpower=0.7, 
                        design=c("2x3x3", "2x2x4", "2x2x3"), 
-                       regulator=c("EMA", "HC", "FDA"), ...) 
+                       regulator=c("EMA", "HC", "FDA", "GCC"), ...) 
 { 
   # Rversion must be >=3.1.0 for the uniroot call with argument extendInt
   Rver <- paste0(R.Version()$major, ".", R.Version()$minor)
